Documentation
=============

.. automodule:: hiperwalk

There are three categories available for
aiding the study of quantum walks.

.. toctree::
    :maxdepth: 1

    graph.rst
    quantum_walk.rst
    plot.rst
